const fs = require('fs');
const path = require('path');
const { createCanvas, loadImage } = require('canvas');

async function convertSvgToPng() {
     try {
          // Define paths
          const svgPath = path.join(__dirname, 'icon.svg');
          const pngPath = path.join(__dirname, 'icon.png');

          // Read SVG content
          const svgContent = fs.readFileSync(svgPath, 'utf8');

          // Extract dimensions from the SVG
          const widthMatch = svgContent.match(/width="(\d+)"/);
          const heightMatch = svgContent.match(/height="(\d+)"/);

          if (!widthMatch || !heightMatch) {
               throw new Error('Could not extract dimensions from SVG');
          }

          const width = parseInt(widthMatch[1], 10);
          const height = parseInt(heightMatch[1], 10);

          // Create a temporary HTML file with the SVG
          const tempHtmlPath = path.join(__dirname, 'temp.html');
          const htmlContent = `
      <html>
        <body style="margin: 0; padding: 0;">
          ${svgContent}
        </body>
      </html>
    `;
          fs.writeFileSync(tempHtmlPath, htmlContent);

          // Create canvas
          const canvas = createCanvas(width, height);
          const ctx = canvas.getContext('2d');

          // Create a data URL for the SVG
          const dataUrl = `data:image/svg+xml;base64,${Buffer.from(svgContent).toString('base64')}`;

          // Load the image
          const img = await loadImage(dataUrl);

          // Draw image on canvas
          ctx.drawImage(img, 0, 0, width, height);

          // Save as PNG
          const out = fs.createWriteStream(pngPath);
          const stream = canvas.createPNGStream();
          stream.pipe(out);

          // Clean up
          out.on('finish', () => {
               fs.unlinkSync(tempHtmlPath);
               console.log(`Converted ${svgPath} to ${pngPath}`);
          });
     } catch (error) {
          console.error('Error converting SVG to PNG:', error);
     }
}

convertSvgToPng(); 